@@ -2,11 +2,11 @@ package WWW::Bugzilla::BugTree;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.014;
 use Moo;
 
 # ABSTRACT: Fetch a tree of bugzilla bugs blocking a bug
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 has ua => (
@@ -50,10 +50,7 @@ sub fetch
     if exists $self->_cache->{$bug_id};
   
   my $url = $self->url->clone;
-  my $path = $url->path;
-  $path =~ s{/$}{};
-  $path .= "/show_bug.cgi";
-  $url->path($path);
+  $url->path(($url->path =~ s{/$}{}r) . "/show_bug.cgi");
   $url->query_form(
     id    => $bug_id,
     ctype => 'xml',
@@ -104,7 +101,7 @@ WWW::Bugzilla::BugTree - Fetch a tree of bugzilla bugs blocking a bug
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -168,8 +165,6 @@ Clears out the cache.
 
 L<bug_tree>, L<WWW::Bugzilla::BugTree::Bug>
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
