@@ -2,13 +2,13 @@ package WWW::Bugzilla::BugTree::Bug;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.014;
 use Moo;
 use XML::Simple qw( XMLin );
 use overload '""' => sub { shift->as_string };
 
 # ABSTRACT: A bug tree returned from WWW::Bugzilla::BugTree
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 has url => (
@@ -79,7 +79,7 @@ WWW::Bugzilla::BugTree::Bug - A bug tree returned from WWW::Bugzilla::BugTree
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
@@ -122,8 +122,6 @@ otherwise.
 
 L<bug_tree>, L<WWW::Bugzilla::BugTree>
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
